@@ -1,5 +1,5 @@
 dc.multinom = function(model, values = NULL, sim.count = 1000, conf.int = 0.95, sigma = NULL, set.seed = NULL, values1 = NULL, values2 = NULL,
-                       type = c("any", "simulation", "bootstrap")){
+                       type = c("any", "simulation", "bootstrap"), summary = TRUE){
   
   # check inputs
   if(is.null(values) && (is.null(values1) || is.null(values2))){
@@ -98,6 +98,11 @@ dc.multinom = function(model, values = NULL, sim.count = 1000, conf.int = 0.95,
   
   diff = pred1 - pred2
   
+  # return all simulated / bootstrapped values if summary is FALSE
+  if(!summary){
+    return(list(pred1 = pred1, pred2 = pred2, dc = diff))
+  }
+  
   confint_lower = (1 - conf.int)/2
   result = matrix(nrow=(n+1),ncol=9)
   colnames(result) = c("Mean1", paste0("1:", 100 * confint_lower, "%"), paste0("1:", 100 * (1 - confint_lower), "%"), 
